#!/bin/sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

. /opt/ibm/director/StorageControl/bin/initSC.sh

IsPasswordChange="no"
IsConfigCheck="no"
LOG=$DIRHOME/log/SCExt.log

#If we were called for Migration, we need to set up the Admin Authority.
function ChangeMigrationAdmin
{
    DB_USER=$(grep rcs.dbuser $DIRHOME/lwi/conf/overrides/database.properties  | awk '{print $3}')
    DB2HOME=$(cat /etc/passwd | grep $DB_USER | awk -F':' '{print $6}')
    . $DB2HOME/sqllib/db2profile

    PATH=$DB2HOME/sqllib/bin:$PATH
    LIBPATH=$DB2HOME/sqllib/lib64:$LIBPATH
    LD_LIBRARY_PATH=$DB2HOME/sqllib/lib64:$LD_LIBRARY_PATH
    export PATH 
    export LIBPATH 
    export LD_LIBRARY_PATH

    echo "PATH:" $PATH >> $LOG
    echo "DB2HOME:" $DB2_HOME >> $LOG
    echo "LIBPATH:" $LIBPATH >> $LOG
    echo "LD_LIBRARY_PATH:" $LD_LIBRARY_PATH >> $LOG
    echo "DB2INSTANCE:" $DB2INSTANCE >> $LOG
    echo "INSTANCENAME:" $INSTANCENAME >> $LOG

    echo "Granting Authorities" >> $LOG
    su - $DB_USER -c "db2set DB2_RESTORE_GRANT_ADMIN_AUTHORITIES=ON"
    if [ $? != 0 ] ; then 
       echo "failed to set DB2_RESTORE_GRANT_ADMIN_AUTHORITIES" >> $LOG
       return 1
    fi
    echo "Granted Authorities" >> $LOG

    su - $DB_USER -c db2stop >> $LOG 2>&1
    if [ $? != 0 ] ; then 
       echo "failed to stop DB2" >> $LOG
       return 1
    fi
    echo "Stopped DB2 server" >> $LOG
    su - $DB_USER -c  db2start >> $LOG 2>&1
    if [ $? != 0 ] ; then 
       echo "failed to start DB2" >> $LOG
       return 1
    fi
    echo "Started DB2 server" >> $LOG
}


#----------------Start of Mainline Code Execution--------------------

if [ -f $DIRHOME/lwi/conf/overrides/old_database.properties ] ; then

# If there is a old_database.properties that means we are called for migration
   ChangeMigrationAdmin

# In case of error we need to check with Director team, whether we need
# to skip migration

else
	#Loop through the command line args until we find an empty one.
   until [ -z "$1" ]
   do
      if [ "$1" == "-p" ] ; then
         #Found a -p flag indicating Password Change call.
         IsPasswordChange="yes"
         break
      elif [ "$1" == "-c" ] ; then
         #Found a -c flag indicating a Config Check call.
         IsConfigCheck="yes"
         break
      fi
      #Shift all the command line args left one.
      shift
   done

   echo "Checking/Changing TPC properties" >> $LOG
   if [ "$IsConfigCheck" == "yes" ] ; then
      #Run the CheckDBProperties.java
      "$JAVAPATH/java"  -cp $CLASSPATH CheckDBProperties $*
      if [ $? != 0 ] ; then
         echo "Failed checking properties $*" >> $LOG
         exit 1
      else
         echo "Successfully checked properties" >> $LOG
      fi
   elif  [ "$IsPasswordChange" == "yes" ] ; then
      #Run the ChangeTPCDB2Properties.java file.
      "$JAVAPATH/java" -cp $CLASSPATH ChangeTPCDB2Properties $DIRHOME $TPCHOME $* >> $LOG 2>&1
      if [ $? != 0 ] ; then
         echo "Failed changin properties $*" >> $LOG
         exit 1
      else
         echo "Successfully changed properties" >> $LOG
      fi
   else
      echo "No options were specified. Invalid usage" >> $LOG
      exit 0
   fi
fi


