#!/bin/sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

CURPATH=$(dirname $0)

. $CURPATH/initSC.sh

#Add the DB2 user ID to the TPCAdmins group
function updateGroupLinux
{
    DB2USER=$(grep rcs.dbuser $DIRHOME/lwi/conf/overrides/database.properties  | awk '{print $3}')

#   if group already exists then return success
    id -nG $DB2USER | grep root > /dev/null 2>&1

    echo "Checking if group exists" >> $MIGLOG 2>&1
    if [ $? -eq 0 ] ; then
       return 0;
    fi
    echo "adding $DB2USER to root group " >> $MIGLOG 2>&1
    if [ -d $DIRHOME/vmi ] ; then
       usermod -A root $DB2USER
    else
       usermod -a -G root $DB2USER
    fi
    echo "Returning after adding - $?" >> $MIGLOG 2>&1
    if [ $? -ne 0 ] ; then
      return 1
    fi
    return 0
}

#Add the DB2 user ID to the TPCAdmins group on AIX.
function updateGroupAIX
{
    DB2USER=$(grep rcs.dbuser $DIRHOME/lwi/conf/overrides/database.properties  | awk '{print $3}')
   GROUPS=$(lsgroup -a -c users system |grep $DB2USER)
   echo "Checking if group exists" >> $MIGLOG 2>&1
   if [ $? -ne 0 ] ; then
      CGROUPS=$(lsgroup -a -c users system |grep system | awk -F ':' '{print $2}')
      CGROUPS=$CGROUPS,$DB2USER
      chgroup users=$CGROUPS system
      echo "Done adding group - $?" >> $MIGLOG 2>&1
   else
      echo "Group exists " >> $MIGLOG 2>&1 
   fi

}

#Helper function to determine which OS to call the update group for.
function updateGroup
{
   OS=$(uname)
   if [ "$OS" == "Linux" ]; then
      updateGroupLinux
      if [ $? -ne 0 ] ; then
         return 1
      fi
   else
#  Assume it is AIX
      updateGroupAIX
      if [ $? -ne 0 ] ; then
         return 1
      fi
   fi
}

#Start Storage Control
function startSC
{
   if [ -e $DIRHOME/StorageControl/bin/startStorageControl.sh ]; then
      $DIRHOME/StorageControl/bin/startStorageControl.sh >> $MIGLOG 2>&1 
   elif [ -e $DIRHOME/bin/startStorageControl.sh ]; then
      $DIRHOME/bin/startStorageControl.sh >> $MIGLOG 2>&1 
   fi
}

#Stop Storage Control
function stopSC
{
   if [ -e $DIRHOME/StorageControl/bin/stopStorageControl.sh ]; then
      $DIRHOME/StorageControl/bin/stopStorageControl.sh >> $MIGLOG 2>&1 
   elif [ -e $DIRHOME/bin/stopStorageControl.sh ]; then
      $DIRHOME/bin/stopStorageControl.sh >> $MIGLOG 2>&1 
   fi
}

MIGLOG=$DIRHOME/log/SCMigrate.log

#Use the specified backup directory if one was given, otherwise use the default.
if [ "$1" != "" ] ; then
  BACKUP_DIR=$1
else
  BACKUP_DIR=/tmp/sc_backup
fi

BACKUPFILE=/tmp/sc_migrate_options.backup
RESTOREFILE=/tmp/sc_migrate_options.restore

#Execute SCMigrateDB.java with the specified parameters.
"$JAVAPATH/java" -DBACKUPDIR=$BACKUP_DIR -DBACKUPFILE=$BACKUPFILE -DRESTOREFILE=$RESTOREFILE -cp $CLASSPATH SCMigrateDB $DIRHOME $TPCHOME $* >> $MIGLOG 2>&1

if [ $? != 0 ] ; then
  displayMessage "MIGRATION_FAILED" >> $MIGLOG 2>&1
  # Remove the backup and restore files if they exist
  rm -f $BACKUPFILE $RESTOREFILE >> $MIGLOG 2>&1
  exit -5
fi

#If the backup file exists then run SCMigDBSupport.sh
if [ -f $BACKUPFILE ] ; then
  $DIRHOME/StorageControl/bin/SCMigDBSupport.sh $BACKUPFILE $DIRHOME
  if [ $? != 0 ] ; then
     displayMessage "MIGRATION_BACKUP_FAILED" >> $MIGLOG 2>&1
     # Remove the backup and restore files if they exist
     rm -f $BACKUPFILE $RESTOREFILE >> $MIGLOG 2>&1
     exit -8
  fi
else
  displayMessage "MIG_BACKUP_NOTFOUND" >> $MIGLOG 2>&1
  # Remove the backup and restore files if they exist
  rm -f $BACKUPFILE $RESTOREFILE >> $MIGLOG 2>&1
  exit -6
fi

#If the restore file exists, then run SCMigDBSupport.sh
if [ -f $RESTOREFILE ] ; then
  $DIRHOME/StorageControl/bin/SCMigDBSupport.sh $RESTOREFILE $DIRHOME
  if [ $? != 0 ] ; then
     displayMessage "MIGRATION_RESTORE_FAILED" >> $MIGLOG 2>&1
     # Remove the backup and restore files if they exist
     rm -f $BACKUPFILE $RESTOREFILE >> $MIGLOG 2>&1
     exit -9
  fi
else
  displayMessage "MIG_RESTORE_NOTFOUND" >> $MIGLOG 2>&1
  # Remove the backup and restore files if they exist
  rm -f $BACKUPFILE $RESTOREFILE >> $MIGLOG 2>&1
  exit -7
fi

#Delete the old TPCDB after a successful migration to Managed DB2
. $BACKUPFILE
echo "Dropping the TPCDB for instance owner $DB_USER..." >> $MIGLOG 2>&1
su - $DB_USER -c "db2 drop database TPCDB" >> $MIGLOG 2>&1
if [ $? -ne 0 ] ; then
	displayMessage "MIGRATION_FAILED" >> $MIGLOG 2>&1
	# Remove the backup and restore files if they exist
	rm -f $BACKUPFILE $RESTOREFILE >> $MIGLOG 2>&1
	exit 2
fi

#Run SCChangeDBCfg.sh
$DIRHOME/StorageControl/bin/SCChangeDBCfg.sh -u -p -v

if [ $? -eq 0 ] ; then
   displayMessage "MIGRATION_SUCCESS" >> $MIGLOG 2>&1
   # Remove the backup and restore files if they exist
   rm -f $BACKUPFILE $RESTOREFILE >> $MIGLOG 2>&1
   echo "Updating group" >> $MIGLOG 2>&1
   updateGroup
   if [ $? -ne 0 ] ; then
      echo "Failed updating group. Please adding $DB2USER manually to 'root' group" >> $MIGLOG 2>&1
   fi
   exit 0
else
   displayMessage "MIGRATION_FAILED" >> $MIGLOG 2>&1
   # Remove the backup and restore files if they exist
   rm -f $BACKUPFILE $RESTOREFILE >> $MIGLOG 2>&1
fi
