@echo OFF
REM Licensed Materials - Property of IBM
REM
REM (C) Copyright IBM Corp. 2011 All Rights Reserved
REM
REM US Government Users Restricted Rights - Use, duplicate or
REM disclosure restricted by GSA ADP Schedule Contract with
REM IBM Corp.

REM Check if SCDEBUG flag is on

   if "%SCDEBUG%"=="1" (@echo on)

   SET BACKUP_DIR=C:\temp\sc_backup
   SET DIRHOME=
   SET JAVAPATH=
   SET TARGET_DIR=%BACKUP_DIR%
   SET VALIDVER="6.3.0"

   SET TPC_HOME=C:\Program Files\ibm\tpc

   if NOT '%1'=='' (
       SET BACKUP_DIR=%1
   )

   if NOT EXIST "%TPC_HOME%\version.txt" (
     SET ERRORLEVEL=0
     GOTO FINALEOF
   )

   call :initializeJava
   
   SET LOG=%DIRHOME%\log\SCRestore.log

   set DIRECDIR=%DIRHOME:\"=%
   set DIRECDIR=%DIRECDIR:\\=\%

   set TMPDIR=c:\temp\sc_backup
   SET BACKUPFILE=%TMPDIR%\sc_migrate_options.backup.bat
   SET RESTOREFILE=%TMPDIR%\sc_migrate_options.restore.bat

   if NOT EXIST %TMPDIR% (
       mkdir %TMPDIR%
   )
   
   %JAVAPATH% -DBACKUPDIR=%BACKUP_DIR% -DBACKUPFILE=%BACKUPFILE% -DRESTOREFILE=%RESTOREFILE% -classpath %CLASSPATH% SCMigrateDB %DIRHOME% %TPC_HOME% 

   if %ERRORLEVEL% NEQ 0  GOTO migrateFailed

   if NOT EXIST %RESTOREFILE% GOTO migrateRestoreNotfound

   REM Check the database.properties file for the current DB location.
   for /f "usebackq tokens=1,2 delims==" %%a in (`type %DIRHOME%\lwi\conf\overrides\database.properties`) do ( 
	if "%%a"=="rcs.DbmsDatabaseAppHome " ( 
		SET DB2HOME=%%b
	) 
   ) 
   
   REM Remove leading spaces from the DB2HOME variable.
   for /f "tokens=* delims= " %%a in ("%DB2HOME%") do set DB2HOME=%%a


   "%DB2HOME%"\bin\db2cmd /w /i /c \%DIRECDIR%\StorageControl\bin\SCMigDBSupport.bat\" %RESTOREFILE%
   if %ERRORLEVEL% NEQ 0 GOTO migrateRestoreFailed

   call :CopyFiles

   if %ERRORLEVEL% NEQ 0 GOTO SCRestoreFailed
   call :displayMessage "SCSAVE_SUCCESS"

   call :cleanupFiles

   GOTO FINALEOF 

:NOT_VALID_DIRECTOR 
   call :displayMessage "ISD_NOT_INSTALLED"
   GOTO FINALEOF 


:initializeJava
   REGEDIT /E DIR_REG.REG "HKEY_LOCAL_MACHINE\SOFTWARE\IBM\IBM Director Server\CurrentVersion" 

   set VALID_DIRECTOR=0

   if NOT EXIST DIR_REG.REG ( 
      goto MY_REG_NO_EXIST 
   ) 

   for /f "usebackq tokens=1,2 delims==" %%a in (`type DIR_REG.REG`) do ( 
    
     if %%a=="Version" ( 
        if %%b GEQ %VALIDVER% ( set VALID_DIRECTOR=1 ) else ( GOTO NOT_VALID_DIRECTOR )
     ) 
     if %%a=="Root" ( 
        SET DIRHOME=%%b
     ) 

   ) 

   SET CLASSPATH=%DIRHOME%\StorageControl\lib\SilentInstall.jar;%DIRHOME%\lwi\lib\passutils.jar;%DIRHOME%\lwi\lib\lwisecurity.jar;%DIRHOME%\StorageControl\lib\eTPCInstallTools.jar
   SET JAVAPATH=%DIRHOME%\jre\bin\java
   GOTO FINALEOF

:displayMessage
   if %VALID_DIRECTOR% EQU 1 (
     %JAVAPATH% -classpath %CLASSPATH% DisplayMessage %1 %2 %3 >> %LOG%
   ) 
   GOTO FINALEOF

:migrateFailed
   call :displayMessage "MIGRATION_FAILED"
   call :cleanupFiles
   GOTO FINALEOF

:migrateRestoreNotfound
   call :displayMessage "MIGRATION_RESTORE_NOT_FOUND"
   call :cleanupFiles
   GOTO FINALEOF

:migrateRestoreFailed
   call :displayMessage "MIGRATION_RESTORE_FAILED"
   call :cleanupFiles
   GOTO FINALEOF

:changeDBFailed
   call :displayMessage "CHANGEDB_FAILED"
   call :cleanupFiles
   GOTO FINALEOF

:SCRestoreFailed
   call :displayMessage "SCRESTORE_FAILED"
   call :cleanupFiles
   GOTO FINALEOF

:CopyFiles

    copy /y %TARGET_DIR%\etpc.javaopt   %DIRHOME%\lwi\conf\overrides >NUL 2>&1
    copy /y %TARGET_DIR%\sc_advmgr.properties %DIRHOME%\proddata\advmgr >NUL 2>&1
    xcopy /y /e %TARGET_DIR%\StorageControl   %DIRHOME% >NUL 2>&1

    GOTO FINALEOF

:cleanupFiles
   REM Remove the backup and restore files if they exist
   del /F %BACKUPFILE% %RESTOREFILE% >> %LOG% 2>&1


:FINALEOF
