@echo OFF
REM Licensed Materials - Property of IBM
REM
REM (C) Copyright IBM Corp. 2011 All Rights Reserved
REM
REM US Government Users Restricted Rights - Use, duplicate or
REM disclosure restricted by GSA ADP Schedule Contract with
REM IBM Corp.

REM There are 3 scenarios when this script gets called

REM 1. This script is called by Director framework when customer moves from
REM    6.2.1 Director to 6.3. Before running the migration, they run some 
REM    pre-config scripts.  During migration from 6.2.1 DB2 to 6.3 embedded DB2
REM    we need to run pre-config for DB2. But for windows we haven't seen.
REM    For linux we needed to run grant authorities for DB2 user on TPCDB
REM 2. When ever Director db2 user password changes, director framework calls
REM    with -p option
REM 3. When ever Director cfgdbcmd.sh is run.  If the database is being changed
REM    Director framework calls with -c <Database Type, DB2, MDB2,SQLServer,
REM    Oracle. We return in error if it is not DB2 or MDB2
REM
REM  This script gets called twice each time.  First with the -c flag to ensure
REM  that the database configuration is valid for our advanced manager before
REM  any changes are made.  If we return zero to the config check, then database
REM  processing continues to make the needed changes.  Once complete, this script
REM  is called a second time to notify us that the changes are complete and that
REM  we need to update the information for our advanced manager.  In this case,
REM  they call us without any parameters, since any variety of options could
REM  have changed.

REM Check if SCDEBUG flag is on
   if "%SCDEBUG%"=="1" (@echo on)

   SET DIRHOME=
   SET JAVAPATH=
   SET VALIDVER="6.3.0"
   SET TPC_HOME="C:\\Program Files\\ibm\\tpc\\"

   SET RETCODE=0

   if NOT EXIST %TPC_HOME%\version.txt (
     GOTO EXITWITHSTATUS
   )

   call :initializeJava

   set LOGFILE=%DIRHOME%\log\SCExt.log

   if EXIST %DIRHOME%\lwi\conf\overrides\old_database.properties GOTO MIGRATION_PATH
 
   SET isConfigCheck=no

REM Loop through the arguments to see if we find the -c flag.

   FOR %%A IN (%*) do (
     if "%%A" == "-c" (
     REM Found -c flag, this is a config check.
               set isConfigCheck=yes
       )
   )

REM For config check, we validate that the database config is ok, but we don't make any changes.
   if "%isConfigCheck%" == "yes" (
   
       call :logThis "Configuration check %*"
       %JAVAPATH% -DSC_DEBUG=True -classpath %CLASSPATH% CheckDBProperties %* >> %LOGFILE%

       	IF ERRORLEVEL 1 (
       	    REM RC 1 indicates that the requested operation is not supported.
			SET RETCODE=1
			GOTO CHECK_FAILED
		) ELSE (
			SET RETCODE=0
			call :logThis "Config check success"
		)
   ) else (
REM  For Config Change, we actually go make changes.
REM  A password change (-p flag) will also get processed here.
       call :logThis "Changing properties %*"
      %JAVAPATH% -classpath %CLASSPATH% ChangeTPCDB2Properties %DIRHOME% %TPC_HOME% %*

		if ERRORLEVEL 1 (
		    REM RC 2 indicates that processing failed.
			SET RETCODE=2
			GOTO CHANGEDB_FAILED
		) ELSE (
			SET RETCODE=0
			call :logThis  "Properties Change Success"
		)

    	call %DIRHOME%\StorageControl\bin\stopStorageControl.bat
       
		if ERRORLEVEL 1 (
			SET RETCODE=1
			GOTO STOPSTORAGECONTROL_FAILED
		) ELSE (
			SET RETCODE=0
			call :logThis "Stop Storage Control Success"
		)
 
 	REM  Must wait for the service to stop / start
	ping 127.0.0.1 -n 30
 
       call %DIRHOME%\StorageControl\bin\startStorageControl.bat

		if ERRORLEVEL 1 (
			SET RETCODE=1
			GOTO STARTSTORAGECONTROL_FAILED
		) ELSE (
			SET RETCODE=0
			call :logThis "Start Storage Control Success"
		)
       
       	REM  Must wait for the service to stop / start
		ping 127.0.0.1 -n 30
       
       
       GOTO EXITWITHSTATUS
   )




       call :logThis "RETCODE=%RETCODE%"


  
   GOTO EXITWITHSTATUS

:logThis
REM All the trace message we log to the file
   echo %1 >> %LOGFILE%
   GOTO FINALEOF

:MIGRATION_PATH
   call :logThis "Migration path "
   
   
   REM Check the database.properties file for the new DatabaseAppHome location.
   for /f "usebackq tokens=1,2 delims==" %%a in (`type %DIRHOME%\lwi\conf\overrides\database.properties`) do ( 
	if "%%a"=="rcs.DbmsDatabaseAppHome " ( 
		SET DB2HOME=%%b
	) 
   )
   
   REM Remove leading spaces from the DB2HOME variable.
   for /f "tokens=* delims= " %%a in ("%DB2HOME%") do set DB2HOME=%%a
     
   call :logThis "DB2HOME=%DB2HOME%"  
   call :logThis "Granting Authorities"
    start /WAIT cmd /C ""%DB2HOME%\bin\db2set" DB2_RESTORE_GRANT_ADMIN_AUTHORITIES=ON"
    if ERRORLEVEL 1 ( 
       call :logThis "failed to set DB2_RESTORE_GRANT_ADMIN_AUTHORITIES"
       REM RC 2 indicates that processing failed.
       SET RETCODE=2
       GOTO EXITWITHSTATUS
    ) ELSE (
		SET RETCODE=0
		call :logThis "Granted Authorities"
	)
    
    "%DB2HOME%"\bin\db2stop >> %LOGFILE%
    if ERRORLEVEL 1 ( 
       call :logThis "failed to stop DB2"
       REM RC 2 indicates that processing failed.
       SET RETCODE=2
       GOTO EXITWITHSTATUS
    ) ELSE (
		SET RETCODE=0
    	call :logThis "Stopped DB2 server"
    )
    
    "%DB2HOME%"\bin\db2start >> %LOGFILE%
    if ERRORLEVEL 1 ( 
       call :logThis "failed to start DB2"
       REM RC 2 indicates that processing failed.
       SET RETCODE=2
       GOTO EXITWITHSTATUS
    ) ELSE (
		SET RETCODE=0
    	call :logThis "Started DB2 server"
	)
   
   
   call :logThis "RETCODE=%RETCODE%"
    
   GOTO EXITWITHSTATUS

:NOT_VALID_DIRECTOR 
   call :logThis "Invalid Director version"
   GOTO EXITWITHSTATUS


:initializeJava
   REGEDIT /E DIR_REG.REG "HKEY_LOCAL_MACHINE\SOFTWARE\IBM\IBM Director Server\CurrentVersion" 

   set VALID_DIRECTOR=0

   if NOT EXIST DIR_REG.REG ( 
      goto MY_REG_NO_EXIST 
   ) 

   for /f "usebackq tokens=1,2 delims==" %%a in (`type DIR_REG.REG`) do ( 
    
     if %%a=="Version" ( 
        if %%b GEQ %VALIDVER% ( set VALID_DIRECTOR=1 ) else ( GOTO NOT_VALID_DIRECTOR )
     ) 
     if %%a=="Root" ( 
        SET DIRHOME=%%b
     ) 

   ) 

   SET CLASSPATH=%DIRHOME%\StorageControl\lib\SilentInstall.jar;%DIRHOME%\lwi\lib\passutils.jar;%DIRHOME%\lwi\lib\lwisecurity.jar;%DIRHOME%\StorageControl\lib\eTPCInstallTools.jar;%TPC_HOME%\uninstallFiles\install\ep_common.jar
   SET JAVAPATH=%DIRHOME%\jre\bin\java
   GOTO FINALEOF

:CHANGEDB_FAILED
   call :logThis "Changing DB2 configuration"
   GOTO EXITWITHSTATUS

:CHECK_FAILED
   call :logThis "Check failed"
   GOTO EXITWITHSTATUS

:STOPSTORAGECONTROL_FAILED
   call :logThis "Stopping Storage Control failed"
   GOTO EXITWITHSTATUS

:STARTSTORAGECONTROL_FAILED
   call :logThis "Stopping Storage Control failed"
   GOTO EXITWITHSTATUS

:MY_REG_NO_EXIST
   call :logThis "Director Registry can't be found"
   GOTO EXITWITHSTATUS

:EXITWITHSTATUS
   exit /b %RETCODE%
:FINALEOF

